pub struct TelescopeCandidate {
pub variable: Symbol,
pub noun_class: Symbol,
pub gender: Gender,
pub origin_box: usize,
pub scope_path: Vec<ScopePath>,
pub in_modal_scope: bool,
}Expand description
A referent that may be accessed via telescoping across sentence boundaries
Fields
variable: Symbolnoun_class: Symbolgender: Genderorigin_box: usizeThe box index where this referent was introduced
scope_path: Vec<ScopePath>Path to navigate AST for scope extension
in_modal_scope: boolWhether this referent was introduced in a modal scope